Ppm

Struct Ppm 

pub struct Ppm<const W: usize, const H: usize> { /* private fields */ }
A NetPBM Portable PixMap (P3; PPM) image.

Implementations

Source

impl<const W: usize, const H: usize> Ppm<W, H>

pub fn new(rows: Vec<Vec<Pixel>>) -> Self

Constructs a PPM image from the given row data.

This method will panic if there are not precisely H rows, or any of the rows do not contain precisely W pixels.

pub unsafe fn new_unchecked(rows: Vec<Vec<Pixel>>) -> Self

Constructs a PPM image from the given row data.

Safety

It is the responsibility of the caller to ensure that rows contains precisely H rows, and that each row contains precisely W pixels.

pub fn gen<F>(f: F) -> Self
where F: Fn(usize, usize) -> Pixel,

Generates a PPM image using the given function in each pixel’s (x,y) coordinates – the top-left corner of the image is (0,0), x grows to the right in the positive direction, and y grows downwards in the positive direction.