pub struct Camera<const W: usize, const H: usize> {
pub gamma: f64,
/* private fields */
}Expand description
A camera in 3D space, with an associated viewport.
The const generic parameters W and H represent the width and height of the viewport in
pixels.
Fields
gamma: f64Implementations
Sourceimpl<const W: usize, const H: usize> Camera<W, H>
impl<const W: usize, const H: usize> Camera<W, H>
Sourcepub unsafe fn new_unchecked(
origin: Vec3,
right: Vec3,
up: Vec3,
focal_length: f64,
gamma: f64,
) -> Self
pub unsafe fn new_unchecked( origin: Vec3, right: Vec3, up: Vec3, focal_length: f64, gamma: f64, ) -> Self
Constructs a camera with the given origin, orientation and focal length.
Safety
It is the responsibility of the caller to ensure that the right and up vectors are
orthonormal.
pub fn sampling_rays_for_pixel( &self, rng: &mut Box<dyn RngCore>, sampling_strategy: Arc<dyn SamplingStrategy>, x: usize, y: usize, ) -> Vec<Ray<f64, 3>>