World

Struct World 

pub struct World { /* private fields */ }
A world, consisting of a set of objects that can be hit by rays.

Implementations

Source

impl World

pub fn new() -> Self

Creates a new world.

pub fn add_object(&mut self, object: Box<dyn Hittable + Send + Sync>)

Adds the given boxed hittable object to this world.

pub fn trace(&self, rng: &mut Box<dyn RngCore>, ray: &Ray) -> Colour

Traces a ray into the world, and returns the resultant colour.