pub struct Ppm<const W: usize, const H: usize> { /* private fields */ }Expand description
A NetPBM Portable PixMap (P3; PPM) image.
Implementations
Sourceimpl<const W: usize, const H: usize> Ppm<W, H>
impl<const W: usize, const H: usize> Ppm<W, H>
Sourcepub fn new(rows: Vec<Vec<Pixel>>) -> Self
pub fn new(rows: Vec<Vec<Pixel>>) -> Self
Constructs a PPM image from the given row data.
This method will panic if there are not precisely H rows, or any of the rows do not contain precisely W pixels.