pub struct Ray<T, const N: usize> {
pub origin: Vector<T, N>,
pub direction: Vector<T, N>,
}Expand description
A ray with an origin and a direction. The direction is normalised.
Fields
origin: Vector<T, N>direction: Vector<T, N>Implementations
Sourceimpl<T, const N: usize> Ray<T, N>
impl<T, const N: usize> Ray<T, N>
Sourcepub fn new(origin: Vector<T, N>, direction: Vector<T, N>) -> Self
pub fn new(origin: Vector<T, N>, direction: Vector<T, N>) -> Self
Constructs a ray from an origin and direction. The given direction is normalised by the callee.
Sourcepub unsafe fn new_unchecked(
origin: Vector<T, N>,
direction: Vector<T, N>,
) -> Self
pub unsafe fn new_unchecked( origin: Vector<T, N>, direction: Vector<T, N>, ) -> Self
Constructs a ray from an origin and direction.
Safety
The caller must ensure that the direction vector is normalised.
Sourcepub fn at(&self, t: T) -> Vector<T, N>
pub fn at(&self, t: T) -> Vector<T, N>
Evaluates this ray at t.
In the case of non-negative t, ray.at(t) is the point that is t units away from the ray’s
origin, in the ray’s direction.
In the case of negative t, ray.at(t) is the point that is -t units away from the ray’s
origin, in the opposite direction to the ray’s direction.